==> v0.3.tar.gz: mailinglist.rb/README.md <==
# mailinglist.rb

## Features

- [x] Receive new message and send it
- [x] Have a database of mailinglists with name and users
- [ ] Web interface to access archives
- [x] ACL to restrict interactions with the system
- [x] Install documentation
- [x] Systemd service
- [ ] AUR package
- [x] Configuration for everything
- [x] Robust codebase for extensibility
- [x] Robust network (handle network loss etc.)
- [ ] Inbox cleanup
- [ ] Moderation toolbox and email validation before distribution

## Deploy from sources

- Note there is a sample of systemd service you may use for your server in `/deploy/`

### Download

    git clone https://git.sceptique.eu/Sceptique/mailinglist.rb --depth 1
    cd mailinglist.rb

### Install dependencies

System dependencies: `ruby 3.1.2`, `sqlite3`

    bundle install

### Configure

Copy and fill all the env variables in .env

    cp empty.env .env
    edit .env

### Setup the database

    bin/db_migrate

### Start

You may test it with

    bin/distributor

### Dev & play localy

After deploying it, there are some tools:

- `bin/db_seed` to generate some data

## Contributing

### via Gitea

1. Fork it (<https://git.sceptique.eu/Sceptique/mailinglistrb>)
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request

### via emails

Checkout git-send-mail tutorial <https://git-send-email.io/>

1. Clone it (<https://git.sceptique.eu/Sceptique/mailinglistrb>)
2. Subscribe to the mailinglist to send your patch <mailto:list.mailinglistrb@sceptique.eu?subject=subscribe> (don't send your patch in this email)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Send your email to <mailto:list.mailinglistrb@sceptique.eu> after you are validated by modo

==> v0.4.tar.gz: mailinglist.rb/README.md <==
# mailinglist.rb

## Features

- [x] Receive new message and send it
- [x] Have a database of mailinglists with name and users
- [ ] Web interface to access archives
- [x] ACL to restrict interactions with the system
- [x] Install documentation
- [x] Systemd service
- [ ] AUR package
- [x] Configuration for everything
- [x] Robust codebase for extensibility
- [x] Robust network (handle network loss etc.)
- [ ] Inbox cleanup
- [x] Moderation toolbox and email validation before distribution

## Deploy from sources

- Note there is a sample of systemd service you may use for your server in `/deploy/`

### Download

    git clone https://git.sceptique.eu/Sceptique/mailinglist.rb --depth 1
    cd mailinglist.rb

### Install dependencies

System dependencies: `ruby 3.1.2`, `sqlite3`

    bundle install

### Configure

Copy and fill all the env variables in .env

    cp empty.env .env
    edit .env

### Setup the database

    bin/db_migrate

### Start

You may test it with

    bin/distributor

### Dev & play localy

After deploying it, there are some tools:

- `bin/db_seed` to generate some data

## Contributing

### via Gitea

1. Fork it (<https://git.sceptique.eu/Sceptique/mailinglistrb>)
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request

### via emails

Checkout git-send-mail tutorial <https://git-send-email.io/>

1. Clone it (<https://git.sceptique.eu/Sceptique/mailinglistrb>)
2. Subscribe to the mailinglist to send your patch <mailto:list.mailinglistrb@sceptique.eu?subject=subscribe> (don't send your patch in this email)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Send your email to <mailto:list.mailinglistrb@sceptique.eu> after you are validated by modo
